{% extends "base.html" %}

{% set title = "Riego - Bewässerungskreise" %}
{% set active_menu = "valves" %}


{% block content %}
<h1>New Item</h1>
<form action="/valves/new" method="POST"
      enctype="multipart/form-data">

      <div class="mb-3">
        <label for="id1" class="form-label">Name</label>
        <input id="id1" name="name" type="text" class="form-control">
      </div>

      <div class="mb-3">
        <label for="id2" class="form-label">channel_nr</label>
        <input id="id2" name="channel_nr"  type="text" class="form-control">
      </div>

      <div class="mb-3">
        <label for="id3" class="form-label">Box_id</label>
        <input id="id3" name="box_id"  type="text" class="form-control">
      </div>


      <input type="submit">
</form>
<hr>
<p>
  <a href="/valves">list</a> 
</p>
{% endblock %}
