{% extends "base.html" %}

{% set title = "Riego - System" %}
{% set active_menu = "system" %}


{% block content %}



<div id='test'>
  <pre>
    {{text}}
  </pre>

</div>


<p>
  <a href="/system/check_update">Check Update</a>
</p>

<p>
  <a href="/system/do_update">Do Update</a>
</p>

<p>
  <a href="/system/restart">Restart</a>
</p>

<p>
  <a href="/system/log_file" target="_blank">View log file</a>
</p>

<p>
    <a href="/system/parameters">Parameter</a>
</p>
  

<p>
  <a href="/system/system_exc">Exception example</a>
</p>



{% endblock %}

